@@ -1078,7 +1078,7 @@ def __create_base__():
 	utils.__save_file__(path, f"SSH_AUTH_SOCK={agent.SSH_AUTH_SOCK}; export SSH_AUTH_SOCK;\nSSH_AGENT_PID={agent.SSH_AGENT_PID}; export SSH_AGENT_PID\n")
 	utils.__set_file_path_permission__(path, permission=755)
 	base = [
-		f"source", path, "&&",
+		f"source {path}", "&&",
 	]
 	return base
 
